@@ -16,7 +16,9 @@ Usage::
     session_client: QLDBClient = session.client("qldb")
     ```
 """
-from mypy_boto3_qldb.client import QLDBClient, QLDBClient as Client
+from mypy_boto3_qldb.client import QLDBClient
+
+Client = QLDBClient
 
 
 __all__ = ("Client", "QLDBClient")
